#!/usr/bin/env perl
#
# NAME:
#	add_secondary.pl - create a slave entry in secondary.zones
#
# SYNOPSIS:
#	add_secondary.pl -Z "zones" "masters" "zone" ...
#
# DESCRIPTION:
#	This script creates an entry in 'secondary.zones' or
#	'named.boot' if that is what we are using, for each "zone"
#	with transfers comming from the nominated "masters".  If more
#	than one master server "masters" should be a coma separated
#	list. 
#	
#	Options:
#
#	-Z "zones"
#		Tells us where to write the entries (secondary.zones).
#		If it contains 'boot' we will assume named.boot
#		(BIND-4) syntax.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: add_secondary.pl,v 1.3 2001/08/30 07:48:33 sjg Exp $
#
#	@(#)Copyright (c) 1997-2001 Simon J. Gerraty.
#	All rights reserved.
#	
#	This software is the property of Simon J. Gerraty.
#	It may be used only in accordance with the conditions outlined
#	in the accompanying LICENSE file. If your distribution does
#	not contain a LICENSE file, then you have no rights to use
#	this software and should contact sales@crufty.net to obtain a
#	licensed distribution.
#	
#	This software is provided "AS IS" in the hope that it will be
#	of use.  Since it is not possible to anticipate all possible
#	use of this software, there is absolutely NO WARRANTY.
#
#	Please forward bug reports and fixes to help@crufty.net
#


if ($0 =~ m,^(.*)/([^/]+)$,) {
  $Mydir = $1;
  $Myname = $2;
} else {
  $Mydir = '.';
  $Myname = $0;
}
$Myname =~ s/\.pl//;

push(@INC, ('.', $Mydir, '/usr/local/lib/perl'));

require 'getopts.pl';
require 'dofile.pl';

$opt_Z = 'secondary.zones';

&do_file(".dnsrc.pl",'.',$ENV{'HOME'},'/etc',$Mydir);
&do_file(".${Myname}rc.pl",'.',$ENV{'HOME'},'/etc',$Mydir);

&Getopts('Z:');

&main;
exit 0;

sub main {
  $masters = shift(@ARGV);
  @masters = split(/,\s*/, $masters);
  $masters = join('; ', @masters); # for BIND-8
  $masters =~ s/\;+$//;

  open(SZ, ">> $opt_Z") || die "$opt_N: $!, stopped at";
  foreach $zone (@ARGV) {
    $zone =~ y/A-Z/a-z/;		# no shouting
    $zone =~ s/\.+$//;
    if ($opt_Z =~ m/boot/) {
      print SZ "secondary\t$zone\t@masters\tsecondary/$zone\n";
    } else {
      print SZ "\nzone \"$zone\" {\n\ttype slave;\n\tfile \"secondary/$zone\";\n\tmasters { $masters; };\n};\n";
    }
  }
  close SZ;
}

