:
# NAME:
#	upd_sndboot - update secondary named.boot
#
# SYNOPSIS:
#	upd_sndboot.sh ["ndboot" ["dnsaddr"]]
#
# DESCRIPTION:
#	This script reads "ndboot" (default is 'named.boot.new') and
#	outputs a named.boot file suitable for a secondary name
#	server.	 If "dnsaddr" is omitted then the IP address of the
#	current host is used.
#
#	Basically, each 'primary' line in "ndboot" is replaced with a
#	'secondary' line with "dnsaddr" being the address to do zone
#	transfers from.
#
#	We expect "ndboot" to contain a line that includes the words
#	`END OF HEADER' and we do not touch anything above that line.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: upd_sndboot.sh,v 1.6 2001/08/30 07:48:38 sjg Exp $
#
#	@(#)Copyright (c) 1994-2001 Simon J. Gerraty.
#	All rights reserved.
#	
#	This software is the property of Simon J. Gerraty.
#	It may be used only in accordance with the conditions outlined
#	in the accompanying LICENSE file. If your distribution does
#	not contain a LICENSE file, then you have no rights to use
#	this software and should contact sales@crufty.net to obtain a
#	licensed distribution.
#	
#	This software is provided "AS IS" in the hope that it will be
#	of use.  Since it is not possible to anticipate all possible
#	use of this software, there is absolutely NO WARRANTY.
#
#	Please forward bug reports and fixes to help@crufty.net
#

Myname=`basename $0 .sh`
Mydir=`dirname $0`
rc=.${Myname}rc

ndboot=${1-named.boot.new}

for d in . $HOME /etc
do
	test -s $d/$rc && { . $d/$rc; break; }
done

dnsaddr=${2-$dnsaddr}

case "$dnsaddr" in
"")
	myname=`uname -n`
	dnsaddr=`grep $myname /etc/hosts | awk '{ print $1 }' | tail -1`
	;;
esac

TF=/tmp/sndb$$

spacefor.sh /tmp 2048  || { echo $Myname: not enough space /tmp >&2; exit 1; }

cat $ndboot > $TF

cat <<!
; DO NOT EDIT THIS FILE
; it was generated by $0 on `date`
!

# make sure some boiler plate is correct...
ok=`grep 'END OF HEADER' $TF`
case "$ok" in
*END*)
	sed -n '1,/END OF HEADER/p' $TF
	sed '1,/END OF HEADER/d' $TF > $TF.x; mv $TF.x $TF
	;;
*)
	test -s named.cache && ca=cache
	cat <<!
; named.boot
directory	`pwd`
cache	.	named.${ca:-ca}
; we pretend to be a primary root server
primary .	db.root
; every name server is primary for loopback
primary 127.in-addr.arpa named.local
; now for real data...
; END OF HEADER - DO NOT REMOVE THIS LINE
!
	;;
esac

grep 'db\.' $TF | while read line
do
	case "$line" in
	*db.in-addr*)
		file=`echo $line | awk '{ print "hosts/" $2 }'`
		;;
	*in-addr*)
		rev=`echo $line | sed 's,.*[ 	]\([0-9][0-9]*\.[0-9][0-9.]*\).in-.*,\1,'`
		fwd=`IFS=.; set -- $rev; echo $4 $3 $2 $1 | tr ' ' '.'`
		file=rev/$fwd.rev
		;;
	*)
		file=`echo $line | awk '{ print "hosts/" $2 }'`
		;;
	esac
	echo $line | sed -e 's/primary/secondary/' -e "s,db\..*,$dnsaddr $file,"
done

# now do the rest
egrep -i '^(secondary|primary)' $TF | egrep -v 'db\.|named\.' |
	sed -e "/^primary/s,^\([^.][^.]*\.[^ 	]*[ 	][ 	]*\),\1 $dnsaddr ," -e 's/primary/secondary/' -e 's/\.[ 	]*$//'

rm -f $TF 
